under

Function under 

pub fn under(
    store: &dyn Store,
    known: &HashMap<&str, Snapshot>,
) -> Result<Vec<Belongs>, Box<dyn Error>>
What is in the store, attributed to the versions passed in.

One walk of the store and not one blob read: what is needed is in the record, which is this store’s cost rule from the first day.