forget

Function forget 

pub fn forget(repo: &Path, working: &Path) -> Result<String, String>
Takes a worktree back out, so the next worktree add on that commit is not refused by a record git kept of one nobody removed.